<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar">
<context>
    <name>GroupNotify</name>
    <message>
        <source>Clear All</source>
        <translation>مسح الكل</translation>
    </message>
    <message>
        <source>Fold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>More</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NotifyCenter</name>
    <message>
        <source>No recent notifications</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NotifyHeader</name>
    <message>
        <source>Notification Center</source>
        <translation>مركز الإخطارات</translation>
    </message>
    <message>
        <source>Clear All</source>
        <translation>مسح الكل</translation>
    </message>
    <message>
        <source>Fold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>More</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NotifySetting</name>
    <message>
        <source>Unpin</source>
        <translation>إزالة الإرفاق</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation>ربط</translation>
    </message>
    <message>
        <source>Notification Setting</source>
        <translation>إعداد الإخطارات</translation>
    </message>
</context>
<context>
    <name>NotifyViewDelegate</name>
    <message>
        <source>Clean All</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>notifycenter::AppNotifyItem</name>
    <message>
        <source>Just now</source>
        <translation>قبل دقيقة واحدة</translation>
    </message>
</context>
</TS>
